'use strict';

/**
 * Supported packings/cipher types.
 * To be useful, any cipher included here must be Authenticated Encryption with Additional Data (AEAD).
 * More preferable versions are numbered higher.
 */
const allVersions = {
  1: {
    version: 1,
    algorithm: 'aes-256-gcm',
    algOptions: {},
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 12,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'scrypt',
    keyBytes: 32,
  },
  2: {
    version: 2,
    algorithm: 'chacha20-poly1305', // Prefer this over NIST because we stan djb
    algOptions: {
      authTagLength: 16,
    },
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 12,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'scrypt',
    keyBytes: 32,
  },
  3: {
    version: 3,
    algorithm: 'xchacha20-poly1305', // Not yet available, but would prefer even more...
    algOptions: {
      authTagLength: 16,
    },
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 24,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'scrypt',
    keyBytes: 32,
  },
  4: {
    version: 4,
    algorithm: 'aes-256-gcm',
    algOptions: {},
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 12,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'shake256',
    keyBytes: 32,
  },
  5: {
    version: 5,
    algorithm: 'chacha20-poly1305',
    algOptions: {
      authTagLength: 16,
    },
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 12,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'shake256',
    keyBytes: 32,
  },
  6: {
    version: 6,
    algorithm: 'xchacha20-poly1305', // Not yet available, but would prefer even more...
    algOptions: {
      authTagLength: 16,
    },
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 24,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'shake256',
    keyBytes: 32,
  },
  7: {
    version: 7,
    algorithm: 'aes-256-gcm',
    algOptions: {},
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 12,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'blake2b512',
    keyBytes: 32,
  },
  8: {
    version: 8,
    algorithm: 'chacha20-poly1305',
    algOptions: {
      authTagLength: 16,
    },
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 12,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'blake2b512',
    keyBytes: 32,
  },
  9: {
    version: 9,
    algorithm: 'xchacha20-poly1305', // Not yet available, but would prefer even more...
    algOptions: {
      authTagLength: 16,
    },
    versionBytes: 1,
    flagsBytes: 1,
    ivBytes: 24,
    saltBytes: 16,
    tagBytes: 16,
    keyDeriver: 'blake2b512',
    keyBytes: 32,
  },
};

module.exports = allVersions;